@@ -1,6 +1,8 @@
 
 __all__ = ['DB']
 
+from sqlalchemy.ext.declarative import declarative_base
+
 from skyext.db.postgre_db import PG
 
 class DB(object):
@@ -29,7 +31,13 @@ class DB(object):
 
     @property
     def model(self):
-        return self._db.model
+        if not self._model:
+            if self._db:
+                self._model = self._db.model
+            else:
+                self._model = declarative_base()
+
+        return self._model
 
     @property
     def session(self):
